(contribute-environments)=

# Contribute Environments

Help advance RL training for the community by contributing new environments. There are several ways to get involved:

---

::::{grid} 1 2 2 2
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`server;1.5em;sd-mr-1` Contribute New Environments
:link: new-environment
:link-type: doc
Contribute novel training environments to NeMo Gym!
+++
{bdg-secondary}`new-environment`
:::
::::

```{toctree}
:caption: Contributing Environments
:hidden:
:maxdepth: 1

New Environment <new-environment>
```

